@@ -71,8 +71,8 @@ aet10_lyt <- function(arm_var,
 aet10_pre <- function(adam_db, ...) {
   adam_db$adae <- adam_db$adae %>%
     filter(.data$ANL01FL == "Y") %>%
-    mutate(AEDECOD = reformat(.data$AEDECOD, nocoding))
-  return(adam_db)
+    mutate(AEDECOD = with_label(reformat(.data$AEDECOD, nocoding), "MedDRA Preferred Term"))
+  adam_db
 }
 
 #' @describeIn aet10 Postprocessing
@@ -116,5 +116,6 @@ aet10_post <- function(tlg, atleast = 0.05, ...) {
 aet10 <- chevron_t(
   main = aet10_main,
   preprocess = aet10_pre,
-  postprocess = aet10_post
+  postprocess = aet10_post,
+  dataset = c("adsl", "adae")
 )
