@@ -144,5 +144,6 @@ cmt01a_post <- function(
 cmt01a <- chevron_t(
   main = cmt01a_main,
   preprocess = cmt01a_pre,
-  postprocess = cmt01a_post
+  postprocess = cmt01a_post,
+  dataset = c("adsl", "adcm")
 )
