@@ -112,7 +112,8 @@ egt02_post <- function(tlg, ...) {
 egt02_1 <- chevron_t(
   main = egt02_1_main,
   preprocess = egt02_pre,
-  postprocess = egt02_post
+  postprocess = egt02_post,
+  dataset = c("adsl", "adeg")
 )
 
 # egt02_2 ----
@@ -137,5 +138,6 @@ egt02_2_main <- modify_default_args(egt02_1_main, exclude_base_abn = TRUE)
 egt02_2 <- chevron_t(
   main = egt02_2_main,
   preprocess = egt02_pre,
-  postprocess = egt02_post
+  postprocess = egt02_post,
+  dataset = c("adsl", "adeg")
 )
