@@ -119,5 +119,6 @@ fstg01_pre <- function(adam_db, ...) {
 #' )
 fstg01 <- chevron_g(
   main = fstg01_main,
-  preprocess = fstg01_pre
+  preprocess = fstg01_pre,
+  dataset = c("adsl", "adrs")
 )
