@@ -42,5 +42,6 @@ lbt15_pre <- function(adam_db, ...) {
 lbt15 <- chevron_t(
   main = lbt04_main,
   preprocess = lbt15_pre,
-  postprocess = lbt04_post
+  postprocess = lbt04_post,
+  dataset = c("adsl", "adlb")
 )
