@@ -213,5 +213,6 @@ mng01_pre <- function(adam_db, dataset, x_var = "AVISIT", ...) {
 #' )
 mng01 <- chevron_g(
   main = mng01_main,
-  preprocess = mng01_pre
+  preprocess = mng01_pre,
+  dataset = c("adsl", "adlb")
 )
