@@ -182,5 +182,6 @@ rspt01_post <- function(tlg, prune_0 = TRUE, ...) {
 rspt01 <- chevron_t(
   main = rspt01_main,
   preprocess = rspt01_pre,
-  postprocess = rspt01_post
+  postprocess = rspt01_post,
+  dataset = c("adsl", "adrs")
 )
