@@ -130,6 +130,19 @@ run(aet10, syn_data)
 ## -----------------------------------------------------------------------------
 run(aet10, syn_data, atleast = 0.08)
 
+## -----------------------------------------------------------------------------
+proc_data <- log_filter(
+  syn_data,
+  PARAMCD %in% c("DIABP", "SYSBP"), "advs"
+)
+run(cfbt01, proc_data, dataset = "advs")
+
+## -----------------------------------------------------------------------------
+run(cfbt01, proc_data, dataset = "advs", skip = list(CHG = c("SCREENING", "BASELINE")))
+
+## -----------------------------------------------------------------------------
+run(cfbt01, proc_data, dataset = "advs", summaryvars = "AVAL")
+
 ## -----------------------------------------------------------------------------
 run(cmt01a, syn_data)
 
